// "House Prices and Government Spending Shocks" -- Hashmat Khan and Abeer Reza, JMCB 2016
// This .mod file contais the dynare version of the Benchmark lender-borrower 
// housing sector model. 
// *****************************************************************

var

cl lambdal nl hl
cb lambdab nb hb lambdab_2
r rn q w pi psi mc
i k b
I K N Y C 
g bg tau
nhl nhb wh r_h  psi_h i_h k_h I_H K_H N_H Y_H H 
shadowl shadowb rr output
;


varexo
eg eps_r;


parameters
delta eta betal phi2 betab gamma theta alpha
C_Y K_Y wn_Y qH_Y rn_ss b_Y m
varrho_r varrho_y varrho_pi varrho_b varrho_g rho_g
Upsilon qhb_Y qhl_Y
deltah delta_h xi phi2_h mu KH_Y wnh_Y YH_Y mul Y_GDP YH_GDP 
I_Y IH_Y
;

//calibration value: 

betal = 0.9925;
betab = 0.97;
eta = 0.5;
xi = 0.8;

delta = 0.025; 
deltah = 0.01;  % Depreciation of housing assets
delta_h = 0.03; % Depreciation of capital in housing production

phi2 = -14.25; 
phi2_h = -10.9;

m = 0.85; 

alpha = 0.5;
gamma = 0.35;
mu = 0.2;
mc_ss = 1/1.15;
theta = 0.83;
 
varrho_r = 0.8;
varrho_pi = 1.5; 
varrho_y = 0.5; 

varrho_b = 0.33; 
varrho_g = 0.1; 
rho_g = 0.9; 

rn_ss = 1/betal; 

// ----------------------------------

C_GDP = 0.65; 
I_GDP = 0.13; 
qYH_GDP = 0.07;
G_GDP = 0.15;
Y_GDP = 1- qYH_GDP;

qH_4GDP = 1.36;
KH_4GDP = 0.04; 

C_Y = C_GDP;
I_Y = I_GDP;
IH_Y = KH_4GDP*4*delta_h;
YH_Y = qYH_GDP;

wn_Y = (1-gamma)*mc_ss; 
wnh_Y = (1-gamma)*qYH_GDP;

qH_Y = qH_4GDP*4;
b_Y = m*qH_Y/rn_ss; 


model;

// Patient Lenders: 

k = (1-delta)*k(-1) + delta*i ;
k_h = (1-delta_h)*k_h(-1) + delta_h*i_h ;

cl =-lambdal  ;
lambdal + w = (xi + (eta-xi)/2)*nl + ((eta-xi)/2)*nhl;
lambdal + wh = (xi + (eta-xi)/2)*nhl + ((eta-xi)/2)*nl;
lambdal + q = betal*(1-deltah)*(q(+1)+lambdal(+1)) - (1-betal*(1-deltah))*hl  ;
psi = delta*phi2*(k(-1) - i) ;
psi= lambdal(+1) - lambdal + betal*((1/betal)-(1-delta))*r(+1) +betal*(1-delta)*psi(+1)+ betal*delta^2*phi2*(k - i(+1)) ;

psi_h = delta_h*phi2_h*(k_h(-1) - i_h) ;
psi_h= lambdal(+1) - lambdal + betal*((1/betal)-(1-delta_h))*r_h(+1) +betal*(1-delta_h)*psi_h(+1)+ betal*delta_h^2*phi2_h*(k_h - i_h(+1)) ;

rn = lambdal - lambdal(+1) + pi(+1)  ;

//Impatient Borrowers: 

C_Y*cb = wn_Y*(w+nb) + wnh_Y*(wh+nhb) + qH_Y*(1-deltah)*(q+hb(-1)) + b_Y*b - tau - qH_Y*(q+hb) - rn_ss*b_Y*(rn(-1)+b(-1)-pi);
b = q(+1) + hb + pi(+1) - rn ;
cb = - lambdab ;
lambdab + w = (xi + (eta-xi)/2)*nb + ((eta-xi)/2)*nhb;
lambdab + wh = (xi + (eta-xi)/2)*nhb + ((eta-xi)/2)*nb;

lambdab + q = betab*(1-deltah)*(q(+1) + lambdab(+1))  + m*betal*(1-betab/betal)*(lambdab_2 + q(+1) + pi(+1) - rn) - (1 - betab*(1-deltah) - m*betal*(1-betab/betal))*hb ;
lambdab = (betab/betal)*(lambdab(+1) + rn - pi(+1)) + (1- (betab/betal))*lambdab_2;

// Firms: 

Y = gamma*K(-1) + (1-gamma)*N ;
r + K(-1) = w + N; 
mc = gamma*w + (1-gamma)*r;

Y_H = mu*K_H(-1) + (1-mu)*N_H;
wh  = q + Y_H - N_H;
r_h = q + Y_H - N_H;

// Price Setting: 
pi = betal*pi(+1) + ((1-theta)*(1-betal*theta)/theta)*mc ;

// Government: 

bg = rn_ss*bg(-1)+ g - tau ;
tau = varrho_b*bg(-1) + varrho_g*g ;
g=rho_g*g(-1)+eg  ;

// Aggregation: 

C=alpha*cb + (1-alpha)*cl;
N =alpha*nb + (1-alpha)*nl;
N_H =alpha*nhb + (1-alpha)*nhl;
H = alpha*hb + (1-alpha)*hl; 

I = i ;
K = k ;
Y = C_Y*C + I_Y*I + IH_Y*I_H + g ;

I_H = i_h ;
K_H = k_h ;
YH_Y*Y_H = qH_Y*H - (1-deltah)*qH_Y*H(-1);

output = (1-YH_Y)*Y + YH_Y*Y_H;

// Monetary Policy

rn = varrho_r*rn(-1) + (1-varrho_r)*(varrho_pi*pi + varrho_y*output)+ eps_r; 

// Auxiliary Variables: 
shadowl = lambdal + q;
shadowb = lambdab + q;
rr = rn - pi(+1); 

end;

steady;
check;

shocks;
var eg; stderr 0.1;
end; 

stoch_simul(nograph, irf=20); 
