// "House Prices and Government Spending Shocks" -- Hashmat Khan and Abeer Reza, JMCB 2016
// This .mod file contais the dynare version of a lender-borrower housing sector 
// model with deep habits. 
// *****************************************************************

var
cl lambdal xl sl nl psi 
cb lambdab xb sb nb
C s
n x
i k 
w r rk pi
mc 
vi vc vg
xg g sg
y
hl hb q lambdab_2 b
shadowl shadowb realR
;


varexo
er varepsilon;


parameters
betal betab alpha
theta psi_c psi_h sigma 
rho_c rho_g 
delta phi2 gamma mc_ss alpha_pi
y_ss epsilon
vc_ss vi_ss vg_ss 
x_y i_y c_y k_y g_y n_ss 
varrho_pi varrho_y varrho_r
varrho_g theta_g xg_y
qhb_y m_ss qH_y qhl_y wn_y
rb_y b_y
;

//calibration value: 

betal = 0.9925;
betab = 0.97; 
gamma = 0.35; 
delta = 0.025; 
phi2 = -14.25; 


alpha = 0.3; 
m_ss = 0.85; 

varrho_pi = 1.5; 
varrho_y = 0.25; 
varrho_r = 0.8; 
varrho_g = 0.8; 

theta = 0.75;
theta_g = 0.75; 
rho_c = 0.95; 
rho_g = 0.95; 

epsilon = 5.6;
alpha_pi = 3.5;

c_y = 0.5; 
g_y = 0.3;
i_y = 1 - c_y - g_y;
k_y = i_y/delta; 
qH_y = 1.36*4; 


x_y = (1-theta)*c_y;
xg_y = (1-theta_g)*g_y;


BBC = (1-betal*rho_c)/(betal*(rho_c-1)*theta - betal*rho_c +1);
BBG = (1-betal*rho_g)/(betal*(rho_g-1)*theta_g - betal*rho_g +1);
mc_ss = 1 - 1/(epsilon*((1-theta)*BBC*c_y + i_y + (1-theta_g)*BBG*g_y));

vi_ss = 1-mc_ss;
vc_ss = (1-mc_ss)*BBC;
vg_ss = (1-mc_ss)*BBG;

n_ss = 0.33;
y_ss = k_y^(gamma/(1-gamma))*n_ss;


sigma = 2.5;

DD = ((1-alpha)/(1-betal) + alpha/(1-betab - m_ss*betal*(1-betab/betal)))*(x_y/qH_y);
EE = (1/((1-gamma)*mc_ss))*x_y*(n_ss/(1-n_ss));
psi_c = EE/(1+EE*(1+DD));
psi_h = psi_c/DD;

qhl_y = (psi_h/psi_c)*(1/(1-betal))*x_y;
qhb_y = (psi_h/psi_c)*(1/(1-betab - m_ss*betal*(1-betab/betal)))*x_y;

// Check Frisch Elasticity: 
eta = ((1-n_ss)/(n_ss))*((1-psi_c*(1-sigma))/(sigma + psi_h*(1-sigma)));

rb_y = m_ss*qhb_y;
b_y = rb_y*betal;
wn_y = (1-gamma)*mc_ss;


model(linear);

// Patient Household: 
xl = (1/(1-theta))*cl - (theta/(1-theta))*sl(-1);
sl = rho_c*sl(-1) + (1-rho_c)*cl;
lambdal = ((1-sigma)*psi_c - 1)*xl -(1-psi_c-psi_h)*(1-sigma)*(n_ss/(1-n_ss))*nl;
(1/(1-betal))*q = xl - hl + (betal/(1-betal))*(lambdal(+1) + q(+1) - lambdal);
w = xl + (n_ss/(1-n_ss))*nl;
r = lambdal - lambdal(+1) + pi(+1);
psi = delta*phi2*(k(-1) - i);
psi = lambdal(+1) - lambdal + betal*((1/betal) - (1-delta))*rk(+1) 
       + betal*(1-delta)*psi(+1) + betal*(delta^2)*phi2*(k - i(+1));
k = (1-delta)*k(-1) + delta*i;

// Impatient Household: 
xb = (1/(1-theta))*cb - (theta/(1-theta))*sb(-1);
sb = rho_c*sb(-1) + (1-rho_c)*cb;
lambdab = ((1-sigma)*psi_c - 1)*xb -(1-psi_c-psi_h)*(1-sigma)*(n_ss/(1-n_ss))*nb;

q = (1-betal)*(xb - hb) + betab*(lambdab(+1) + q(+1) - lambdab) 
   + m_ss*betal*(1-(betab/betal))*(lambdab_2 + q(+1) + pi(+1) - r);
w = xb + (n_ss/(1-n_ss))*nb;
lambdab_2 = (betab/(betal-betab))*(lambdab - lambdab(+1) - r);
b = q(+1) + hb + pi(+1) - r; 
c_y*cb + qhb_y*(q + hb) + rb_y*(r(-1) + b(-1) - pi)= wn_y*(w+nb) + qhb_y*(q + hb(-1)) + b_y*b - g_y*g;



// Production: 
y = gamma*k(-1) + (1-gamma)*n;
rk + k(-1) = w + n;
mc = (1-gamma)*w + gamma*rk; 


// Rotemberg for Deep Habits: 
vi = -(mc_ss/(1-mc_ss))*mc; 
vc = - (mc_ss/vc_ss)*mc 
      - (betal/vc_ss)*((theta*(rho_c-1)-rho_c)*vc_ss + rho_c*(1-mc_ss))*(lambdal(+1) - lambdal)
      - betal*(theta*(rho_c-1)- rho_c)*vc(+1)
      + (mc_ss/vc_ss)*betal*rho_c*mc(+1);
vg = - (mc_ss/vg_ss)*mc 
      - (betal/vg_ss)*((theta_g*(rho_g-1)-rho_g)*vg_ss + rho_g*(1-mc_ss))*(lambdal(+1) - lambdal)
      - betal*(theta_g*(rho_g-1)- rho_g)*vc(+1)
      + (mc_ss/vg_ss)*betal*rho_g*mc(+1);
(alpha_pi/y_ss)*pi = (alpha_pi/y_ss)*betal*pi(+1) 
                    - epsilon*vc_ss*x_y*(vc + x)
                    - epsilon*vg_ss*xg_y*(vg + xg)
                    - epsilon*vi_ss*i_y*i 
                    + y;

// Government: 
xg = (1/(1-theta_g))*g - (theta_g/(1-theta_g))*sg(-1);
sg = rho_g*sg(-1) + (1-rho_g)*xg;
g = varrho_g*g(-1) + varepsilon; 

// Monetary Policy: 
r = 0.8*r(-1) + 0.2*(varrho_pi*pi + 0.15*y) + er; 

// Aggregation:
C = (1-alpha)*cl + alpha*cb;
x = (1-alpha)*xl + alpha*xb;
s = (1-alpha)*sl + alpha*sb;
n = (1-alpha)*nl + alpha*nb;
0 = (1-alpha)*qhl_y*hl + alpha*qhb_y*hb;


y = c_y*C + i_y*i + g_y*g;

// Auxiliary Variables: 
shadowl = lambdal + q;
shadowb = lambdab + q;
realR = r - pi(+1);

end;

steady;
check;

shocks;
var varepsilon; stderr 0.1;
end; 

stoch_simul(nograph, irf=20); 



