% *************************************************************************
%  Khan, Hashmat and Abeer Reza (2016), "House Prices and Government
%  Spending Shocks", Journal of Money, Credit and Banking
% 
%  Replication File for Figure 5
% *************************************************************************


clear all;
clc;

q = [];
cl = [];
cb = [];
lambdal = [];
lambdab = [];

for ii = 1:5;
    if ii == 1;
        dynare FixedH.mod noclearall;       % Fixed Housing
    elseif ii == 2;
        dynare Struc.mod noclearall;        % Housing Production and sticky home prices
    elseif ii ==3; 
        dynare GHH.mod noclearall;          % GHH Preferences
    elseif ii ==4;
        dynare Edgeworth.mod noclearall;    % Edgeworth Complementarity in Housing        
    elseif ii ==5;
        dynare Deep.mod noclearall;         % Deep Habits
    end;
        
 q(:,ii) = q_varepsilon;
 cl(:,ii) = cl_varepsilon;
 cb(:,ii) = cb_varepsilon;
 shadowl(:,ii) = shadowl_varepsilon;
 shadowb(:,ii) = shadowb_varepsilon;
end; 

T = [1:size(q,1)];
X0 = zeros(size(q,1));

figure('Position',[500 50 800 900]);
for ii = 1:5;
subplot(5,3,(ii-1)*3+1);
plot(T,q(:,ii),'-k', T,X0,'-r','LineWidth',1.25);
axis tight;
title('House Prices');
if ii ==1;
    ylabel('Fixed Housing');
elseif ii ==2;
    ylabel('Sticky Home Prices');
elseif ii ==3;
    ylabel('GHH Preferences');
elseif ii ==4;
    ylabel('Edgeworth Complem.');
elseif ii ==5;
    ylabel('Deep Habits');
end;
    
subplot(5,3,(ii-1)*3+2);
plot(T,cl(:,ii),'--k',T,cb(:,ii),':k',T,X0,'-r','LineWidth',1.25);
axis tight;
title('Consumption');
subplot(5,3,(ii-1)*3+3);
plot(T,shadowl(:,ii),'--k',T,shadowb(:,ii),':k',T,X0,'-r','LineWidth',1.25);
axis tight;
title('Shadow Value');
end;

save2pdf('Figure5');

