// "House Prices and Government Spending Shocks" -- Hashmat Khan and Abeer Reza, JMCB 2016
// This .mod file contains the dynare version of a lender-borrower housing sector 
// model with Fixed Housing and no wage rigidities
// *****************************************************************

var

cl lambdal nl hl
cb lambdab nb hb lambdab_2
r rn R q w pi psi 
mc
i k b 
I K N Y C
g bg tau 
shadowl shadowb
realR
;


varexo
varepsilon;


parameters
delta eta betal phi2 betab gamma theta alpha
C_Y K_Y wn_Y qH_Y R_ss b_Y m
varrho_pi varrho_b varrho_g rho_g
Upsilon qhb_Y qhl_Y
;

//calibration value: 

m = 0.85; 
alpha = 0.5; 


betal = 0.9925;
betab = 0.97;
eta = 1;
gamma = 0.35; 
delta = 0.025; 
theta = 0.75; 
varrho_pi = 1.5; 
varrho_b = 0.33; 
varrho_g = 0.1; 
rho_g = 0.9; 
phi2 = -14.25; 
R_ss = 1/betal; 

C_Y = 0.5; 
K_Y = 2.05*4; 
qH_Y = 1.36*4; 
b_Y = m*betal*qH_Y; 
mc_ss = 1/1.15; 
wn_Y = (1-gamma)*mc_ss; 


A = alpha / (1 - betab - m*betal*(1-betab/betal)); 
B = (1-alpha)/(1-betal);
Upsilon = qH_Y/(C_Y*(A+B));

// Alternatively, set Upsilon_b and Upsilon_l to match qH_Y;
Upsilon_b = (qH_Y/C_Y)*(1-betab - m*betal*(1-betab/betal));
Upsilon_l = (qH_Y/C_Y)*(1-betal);
qhb_Y = qH_Y;
qhl_Y = qH_Y;

model;

// Patient Lenders: 

k = (1-delta)*k(-1) + delta*i ;
cl =-lambdal  ;
lambdal + q = betal*(q(+1)+lambdal(+1)) - (1-betal)*hl  ;
psi = delta*phi2*(k(-1) - i) ;
psi= lambdal(+1) - lambdal + betal*((1/betal)-(1-delta))*r(+1) +betal*(1-delta)*psi(+1)+ betal*delta^2*phi2*(k - i(+1)) ;
rn = lambdal - lambdal(+1) + pi(+1)  ;

//Impatient Borrowers: 

C_Y*cb = wn_Y*(w+nb) + qH_Y*hb(-1) + b_Y*b - tau - qH_Y*hb - R_ss*b_Y*( R(-1)+b(-1)-pi) ;
b = q(+1) + hb + pi(+1) - R ;
cb =-lambdab ;
lambdab + q = betab*(q(+1) + lambdab(+1))  + m*betal*(1-betab/betal)*(lambdab_2 + q(+1) + pi(+1) - R) - (1 - betab - m*betal*(1-betab/betal))*hb ;
lambdab = (betab/betal)*(lambdab(+1) + R - pi(+1)) + (1- (betab/betal))*lambdab_2;

// Firms: 

Y = gamma*K(-1) + (1-gamma)*N ;
r + K(-1) = w + N;

// Price Setting and Monetary Policy: 

mc = (1-gamma)*w + gamma*r; 
pi = betal*pi(+1) + ((1-theta)*(1-betal*theta)/theta)*mc ;

// Monetary Policy: 

rn = 0.8*rn(-1) + 0.2*(varrho_pi*pi + 0.15*Y); 

// Government: 

bg = R_ss*bg(-1)+ g - tau ;
tau = varrho_b*bg + varrho_g*g ;
g=rho_g*g(-1)+varepsilon  ;

// Aggregation: 

C=alpha*cb + (1-alpha)*cl ;
N =alpha*nb + (1-alpha)*nl ;
0=alpha*hb + (1-alpha)*hl ;
I = (1-alpha)*i ;
K = (1-alpha)*k ;
Y = C_Y*C + delta*K_Y*I + g ;
R = rn; 

// Labour Wage Setting: 
// Competitive: 
eta*nl = lambdal + w ;
eta*nb = lambdab + w ;

// Auxiliary Variables: 
shadowl = lambdal + q;
shadowb = lambdab + q;
realR = R - pi(+1);
end;

steady;
check;

shocks;
var varepsilon; stderr 0.1;
end; 

stoch_simul(nograph, irf=20); 

