// "House Prices and Government Spending Shocks" -- Hashmat Khan and Abeer Reza, JMCB 2016
// This .mod file contais the dynare version of a lender-borrower housing sector 
// model with HOUSING PRODUCTION 
// *************************************************************

var

cl lambdal nl hl
cb lambdab nb hb lambdab_2
r rn R q w pi psi mc
mc
i k b
I K N Y C 
g bg tau
nhl nhb wh r_h  psi_h i_h k_h I_H K_H N_H Y_H H 
shadowl shadowb
mc_h pi_h
;


varexo
varepsilon eps_r;


parameters
delta eta betal phi2 betab gamma theta alpha
C_Y K_Y wn_Y qH_Y R_ss b_Y m
varrho_pi varrho_b varrho_g rho_g
Upsilon qhb_Y qhl_Y
delta_h deltah xi phi2_h mu KH_Y wnh_Y YH_Y mul Y_GDP YH_GDP
;

//calibration value: 

betal = 0.9925;
betab = 0.97;
eta = 1;
gamma = 0.35; 
delta = 0.025; 
theta = 0.83; 
varrho_pi = 1.5; 
varrho_b = 0.33; 
varrho_g = 0.1; 
m = 0.85; 
rho_g = 0.9; 
phi2 = -14.25; 
R_ss = 1/betal; 

C_Y = 0.5; 
K_Y = 2.05*4; 
qH_Y = 1.36*4; 
mc_ss = 1/1.15; 
wn_Y = (1-gamma)*mc_ss; 

alpha = 0.5; 

b_Y = m*betal*qH_Y; 

delta_h = 0.03;
xi = 1;
phi2_h = -10.9;
mu = 0.2; 
mul = 0.1;
KH_Y = 0.04*4; 
YH_Y = 0.12; 
wnh_Y = (1-mu-mul)*YH_Y*mc_ss;
deltah = YH_Y/qH_Y;
Y_GDP = 1/(YH_Y +1);
YH_GDP = 1- Y_GDP;

model;

// Patient Lenders: 

k = (1-delta)*k(-1) + delta*i ;
cl =-lambdal  ;
lambdal + q = betal*(1-deltah)*(q(+1)+lambdal(+1)) - (1-betal*(1-deltah))*hl  ;
psi = delta*phi2*(k(-1) - i) ;
psi= lambdal(+1) - lambdal + betal*((1/betal)-(1-delta))*r(+1) +betal*(1-delta)*psi(+1)+ betal*delta^2*phi2*(k - i(+1)) ;
rn = lambdal - lambdal(+1) + pi(+1)  ;

//Impatient Borrowers: 

C_Y*cb = wn_Y*(w+nb) + wnh_Y*(wh+nhb) + qH_Y*(1-deltah)*(q+hb(-1)) + b_Y*b - tau - qH_Y*(q+hb) - R_ss*b_Y*( R(-1)+b(-1)-pi);
b = q(+1) + hb + pi(+1) - R ;
cb = - lambdab ;
lambdab + q = betab*(1-deltah)*(q(+1) + lambdab(+1))  + m*betal*(1-betab/betal)*(lambdab_2 + q(+1) + pi(+1) - R) - (1 - betab*(1-deltah) - m*betal*(1-betab/betal))*hb ;
lambdab = (betab/betal)*(lambdab(+1) + R - pi(+1)) + (1- (betab/betal))*lambdab_2;

// Firms: 

Y = gamma*K(-1) + (1-gamma)*N ;
r + K(-1) = w + N;

// Price Setting and Monetary Policy: 
mc = (1-gamma)*w + gamma*r; 
pi = betal*pi(+1) + ((1-theta)*(1-betal*theta)/theta)*mc ;

// Government: 

bg = R_ss*bg(-1)+ g - tau ;
tau = varrho_b*bg(-1) + varrho_g*g ;
g=rho_g*g(-1)+varepsilon  ;

// Aggregation: 

C=alpha*cb + (1-alpha)*cl ;
N =alpha*nb + (1-alpha)*nl ;
I = (1-alpha)*i ;
K = (1-alpha)*k ;
Y = C_Y*C + delta*K_Y*I + g ;

R = rn; 

// Labour Wage Setting: 

lambdal + w = (xi + (eta-xi)/2)*nl + ((eta-xi)/2)*nhl;
lambdab + w = (xi + (eta-xi)/2)*nb + ((eta-xi)/2)*nhb;
lambdal + wh = (xi + (eta-xi)/2)*nhl + ((eta-xi)/2)*nl;
lambdab + wh = (xi + (eta-xi)/2)*nhb + ((eta-xi)/2)*nb;

// Infrastructure equation: 
k_h = (1-delta_h)*k_h(-1) + delta*i_h ;
psi_h = delta_h*phi2_h*(k_h(-1) - i_h) ;
psi_h= lambdal(+1) - lambdal + betal*((1/betal)-(1-delta_h))*r_h(+1) +betal*(1-delta_h)*psi_h(+1)+ betal*delta_h^2*phi2_h*(k_h - i_h(+1)) ;
r_h + K_H(-1) = wh + N_H;
Y_H = mu*K_H(-1) + (1-mu-mul)*N_H;
N_H =alpha*nhb + (1-alpha)*nhl ;
H = alpha*hb + (1-alpha)*hl; 
I_H = (1-alpha)*i_h ;
K_H = (1-alpha)*k_h ;
YH_Y*Y_H = qH_Y*H - (1-deltah)*qH_Y*H(-1);

// Nominal rigidities in Infrastructure price setting: 

mc_h = (1-mu-mul)*wh + mu*r_h; 
pi_h = betal*pi_h(+1) + ((1-theta*2)*(1-betal*theta*2)/theta*2)*mc_h ;
pi_h = q - q(-1);

// Monetary Policy

rn = 0.8*rn(-1) + 0.2*(varrho_pi*pi + varrho_pi*pi_h+ 0.15*Y)+ eps_r; 

// Auxiliary Variables: 
shadowl = lambdal + q;
shadowb = lambdab + q;

end;

steady;
check;

shocks;
var varepsilon; stderr 0.1;
var eps_r; stderr 0.1;
end; 

stoch_simul(nograph, irf=20); 

